@@ -473,7 +473,8 @@ eog_full_screen_key_press (GtkWidget *widget, GdkEventKey *event)
 	case GDK_Right:
 	case GDK_Down:
 	case GDK_Page_Down:
-		if (!priv->slide_show && eog_image_list_length (priv->list) > 1) {
+		if (!priv->slide_show && eog_image_list_length (priv->list) > 1 &&
+		    !eog_scroll_view_scrollbars_visible (EOG_SCROLL_VIEW (priv->view))) {
 			priv->direction = EOG_DIRECTION_FORWARD;
 			
 			next = get_next_iter_in_direction (priv->list, priv->current, 
@@ -491,7 +492,8 @@ eog_full_screen_key_press (GtkWidget *widget, GdkEventKey *event)
 	case GDK_Left:
 	case GDK_Up:
 	case GDK_Page_Up:
-		if (!priv->slide_show && eog_image_list_length (priv->list) > 1) {
+		if (!priv->slide_show && eog_image_list_length (priv->list) > 1 &&
+		    !eog_scroll_view_scrollbars_visible (EOG_SCROLL_VIEW (priv->view))) {
 			priv->direction = EOG_DIRECTION_BACKWARD;
 
 			next = get_next_iter_in_direction (priv->list, priv->current, priv->direction);
@@ -538,6 +540,11 @@ eog_full_screen_key_press (GtkWidget *widget, GdkEventKey *event)
 	}
 
 	if (do_hide) {
+		cancel_load_by_iter (priv->list, priv->preload);
+		if (priv->preload != NULL) {
+			g_free (priv->preload);
+			priv->preload = NULL;
+		}
 		gtk_widget_hide (widget);
 	}
 
@@ -692,6 +699,12 @@ job_image_load_finished  (EogJob *job, gpointer data, GError *error)
 	EogImage *current_img;
 	EogImage *preload_img;
 
+	if (eog_job_get_status (job) == EOG_JOB_STATUS_CANCELED) {
+		g_object_set_qdata (G_OBJECT (image), JOB_ID_QUARK, NULL);
+		eog_image_data_unref (image);
+		return;
+	}
+
 	if (eog_job_get_success (job))
 		eog_image_cache_add (priv->cache, image);
 
@@ -828,7 +841,7 @@ eog_full_screen_new (GtkWindow *parent,
 	style->bg    [GTK_STATE_NORMAL] = style->black;
 	style->bg_gc [GTK_STATE_NORMAL] = style->black_gc;
 	if (style->bg_pixmap [GTK_STATE_NORMAL])
-		gdk_pixmap_unref (style->bg_pixmap [GTK_STATE_NORMAL]);
+		g_object_unref (style->bg_pixmap [GTK_STATE_NORMAL]);
 	style->bg_pixmap [GTK_STATE_NORMAL] = NULL;
 
 	gtk_widget_set_style (widget, style);
